==> openGion6.3.8.5_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF25S.sql <==
/****************************************************************************/
/* GF25 ( JAVADOC属性定義ﾌｧｲﾙ )                                             */
/*                                                                          */
/* Created : 2015/09/17 15:31:10                                            */
/****************************************************************************/
CREATE TABLE GF25 (
   VERNO        VARCHAR2 (   10 )                   NOT NULL            /*  10 ﾊﾞｰｼﾞｮﾝ      */
 , ATTCLASS     VARCHAR2 (  100 )                   NOT NULL            /*  20 ATTCLASS     */
 , SEQ          NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  30 順           */
 , ATTKEY       VARCHAR2 (   30 )                   NOT NULL            /*  40 属性ｸﾗｽ      */
 , VALUENAME    VARCHAR2 (   30 )                   NOT NULL            /*  50 属性名称     */
 , DESCRIPTION  VARCHAR2 ( 4000 )                                       /*  60 概要説明     */
 , CONTENTS     CLOB                                                    /*  70 内容         */
 , FORM_SAMPLE  CLOB                                                    /*  80 形式ｻﾝﾌﾟﾙ    */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF25S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF25T00 
  BEFORE INSERT ON GF25
  FOR EACH ROW 
  BEGIN 
    SELECT GF25S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.0.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF25S.sql <==
/****************************************************************************/
/* GF25 ( JAVADOC属性定義ﾌｧｲﾙ )                                             */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF25 (
   VERNO        VARCHAR2 (   10 )                   NOT NULL            /*  10 ﾊﾞｰｼﾞｮﾝ      */
 , ATTCLASS     VARCHAR2 (  100 )                   NOT NULL            /*  20 ATTCLASS     */
 , SEQ          NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  30 順           */
 , ATTKEY       VARCHAR2 (   30 )                   NOT NULL            /*  40 属性ｸﾗｽ      */
 , VALUENAME    VARCHAR2 (   30 )                   NOT NULL            /*  50 属性名称     */
 , DESCRIPTION  VARCHAR2 ( 4000 )                                       /*  60 概要説明     */
 , CONTENTS     CLOB                                                    /*  70 内容         */
 , FORM_SAMPLE  CLOB                                                    /*  80 形式ｻﾝﾌﾟﾙ    */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF25S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF25T00 
  BEFORE INSERT ON GF25
  FOR EACH ROW 
  BEGIN 
    SELECT GF25S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
